==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebDropdownHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownHeaderDescription } from "./WebDropdownHeaderDescription";
/**
 * @hidden
 */
export let WebDropdownHeaderDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDropdownHeaderDescriptionMetadata extends Base {
        static b(a) {
            if (WebDropdownHeaderDescriptionMetadata.a == null) {
                WebDropdownHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDropdownHeaderDescriptionMetadata.c(WebDropdownHeaderDescriptionMetadata.a);
            }
            if (a.j(WebDropdownHeaderDescriptionMetadata.a)) {
                return;
            }
            a.y(WebDropdownHeaderDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DropdownHeader");
            a.item("__tagNameWC", "String:igc-dropdown-header");
        }
        static d(a) {
            WebDropdownHeaderDescriptionMetadata.b(a);
            a.aa("WebDropdownHeader", () => new WebDropdownHeaderDescription());
            a.z("WebDropdownHeader", WebDropdownHeaderDescriptionMetadata.a);
        }
    }
    WebDropdownHeaderDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDropdownHeaderDescriptionMetadata, 'WebDropdownHeaderDescriptionMetadata');
    WebDropdownHeaderDescriptionMetadata.a = null;
    return WebDropdownHeaderDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebDropdownHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownHeaderDescription } from "./WebDropdownHeaderDescription";
/**
 * @hidden
 */
export let WebDropdownHeaderDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDropdownHeaderDescriptionMetadata extends Base {
        static b(a) {
            if (WebDropdownHeaderDescriptionMetadata.a == null) {
                WebDropdownHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDropdownHeaderDescriptionMetadata.c(WebDropdownHeaderDescriptionMetadata.a);
            }
            if (a.k(WebDropdownHeaderDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebDropdownHeaderDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:DropdownHeader");
            a.item("__tagNameWC", "String:igc-dropdown-header");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebDropdownHeaderDescriptionMetadata.b(a);
            a.ac("WebDropdownHeader", () => new WebDropdownHeaderDescription());
            a.ab("WebDropdownHeader", WebDropdownHeaderDescriptionMetadata.a);
        }
    }
    WebDropdownHeaderDescriptionMetadata.$t = /*@__PURE__*/ markType(WebDropdownHeaderDescriptionMetadata, 'WebDropdownHeaderDescriptionMetadata');
    WebDropdownHeaderDescriptionMetadata.a = null;
    return WebDropdownHeaderDescriptionMetadata;
})();
